pub struct RootChain { /* private fields */ }Expand description
This chain starts with an initial shared secret key and is maintained by both parties in order to derive sending and receiving chain keys, taking Diffie-Hellman agreements as input.
Implementations